
import React, { useCallback, useEffect, useRef, useState } from 'react'
import moment from 'moment';
import { Badge, Image, DatePicker, Select } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getList, exportList } from '@/services/work'
import PageTable from '@/components/PageTable'
import useOrgList from '@/utils/hooks/useOrgList';

const { RangePicker } = DatePicker;
const { Option } = Select;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};


export default (props) => {
  const actionRef = useRef();
  const [start, setStartDate] = useState()
  const [end, setEndDate] = useState()
  const [orgId, setOrgId] = useState()
  const { orgList } = useOrgList()

  const handelDateChange = useCallback((date, dateStrings) => {
    setStartDate(dateStrings[0])
    setEndDate(dateStrings[1])
  }, [])

  const handleReset = useCallback(() => {
    setStartDate()
    setEndDate()
    actionRef.current.reload();
  }, [])

  const columns = [
    {
      title: '企业名称',
      dataIndex: 'orgId',
      key: 'orgId',
      search: true,
      render: t => orgList.filter(x => x.orgId === t)[0]?.orgName,
      renderFormItem: () => (
        <Select>
          {orgList.map((item) => (
            <Option value={item.orgId} key={item.orgId}>
              {item.orgName}
            </Option>
          ))}
        </Select>
      )
    },
    {
      title: '申请人',
      dataIndex: 'userName',
      key: 'userName',
      search: true,
    },
    {
      title: '抗原截图',
      dataIndex: 'antigenImage',
      key: 'antigenImage',
      search: false,
      render: t => <Image src={t} width="64px" height="64px" />
    },
    {
      title: '抗原结果',
      dataIndex: 'antigenIsNormal',
      key: 'antigenIsNormal',
      search: false,
      render: t => (
        <span>
          {t ? <Badge status="success" text="正常" /> : <Badge status="error" text="异常" />}
        </span>
      )
    },
    {
      title: '核酸截图',
      dataIndex: 'nucleicImage',
      key: 'nucleicImage',
      search: false,
      render: t => <Image src={t} width="64px" height="64px" />
    },
    {
      title: '核酸结果',
      dataIndex: 'nucleicIsNormal',
      key: 'nucleicIsNormal',
      search: false,
      render: t => (
        <span>
        {t ? <Badge status="success" text="正常" /> : <Badge status="error" text="异常" />}
        </span>
      )
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' onChange={handelDateChange} />
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        request={getList}
        expfunc={exportList}
        options={false}
        params={{ start, end }}
        onReset={handleReset}
        rowKey="formId"
      />
    </PageHeaderWrapper>
  )
}
